==> trade-center-api-2.4.10-20220221.125008-1-sources.jar: cn/com/duiba/order/center/api/dto/OrderFlowworkOperationDataDto.java <==
package cn.com.duiba.order.center.api.dto;

import java.io.Serializable;

/**
 * Created by yansen on 17/2/15.
 */
public class OrderFlowworkOperationDataDto implements Serializable{

    private static final long serialVersionUID = 8767237839095224161L;

    public static final int TYPE_FORCE_SUPPLIER_SUCCESS=1;//

    public static final int TYPE_FORCE_SUPPLIER_FAIL=2;//

    public static final int TYPE_MNG_SUPPLIER_SUCCESS=3;//管理员后台上游兑换成功

    public static final int TYPE_MNG_SUPPLIER_FAIL=4;//管理员后台上游兑换失败

    public static final int TYPE_CONSUME_CREDITS_SUCCESS=5;//扣积分成功

    public static final int TYPE_CONSUME_CREDITS_FAIL=6;//扣积分失败
    
    public static final int TYPE_CONSUME_POSTSALE_COMPLETE=7;//售后完成

    /**  苏州银行强制订单失败  */
    public static final int TYPE_SZBANK_FORCE_ORDER_FAIL = 8;
    /**  业务主体变更强制订单失败  */
    public static final int TYPE_SUBJECT_FORCE_ORDER_FAIL = 9;

    public static final int TYPE_CONSUME_POSTSALE_CREDITS=10;//售后积分

    private Integer type;

    private Long orderId;

    private Long appId;

    private Long postsaleOrderNum;

    private Long orderItemId;

    private Boolean isPureCredits;

    private Long postsaleCredits;

    private Long postsaleOrderId;

    private String error4admin;

    private String error4developer;

    private String error4consumer;

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Long getOrderId() {
        return orderId;
    }

    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }

    public String getError4admin() {
        return error4admin;
    }

    public void setError4admin(String error4admin) {
        this.error4admin = error4admin;
    }

    public String getError4developer() {
        return error4developer;
    }

    public void setError4developer(String error4developer) {
        this.error4developer = error4developer;
    }

    public String getError4consumer() {
        return error4consumer;
    }

    public void setError4consumer(String error4consumer) {
        this.error4consumer = error4consumer;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getOrderItemId() {
        return orderItemId;
    }

    public void setOrderItemId(Long orderItemId) {
        this.orderItemId = orderItemId;
    }

    public Long getPostsaleCredits() {
        return postsaleCredits;
    }

    public void setPostsaleCredits(Long postsaleCredits) {
        this.postsaleCredits = postsaleCredits;
    }

    public Long getPostsaleOrderNum() {
        return postsaleOrderNum;
    }

    public void setPostsaleOrderNum(Long postsaleOrderNum) {
        this.postsaleOrderNum = postsaleOrderNum;
    }

    public Boolean getPureCredits() {
        return isPureCredits;
    }

    public void setPureCredits(Boolean pureCredits) {
        isPureCredits = pureCredits;
    }

    public Long getPostsaleOrderId() {
        return postsaleOrderId;
    }

    public void setPostsaleOrderId(Long postsaleOrderId) {
        this.postsaleOrderId = postsaleOrderId;
    }
}

==> trade-center-api-2.4.15-20220315.025912-29-sources.jar: cn/com/duiba/order/center/api/dto/OrderFlowworkOperationDataDto.java <==
package cn.com.duiba.order.center.api.dto;

import java.io.Serializable;
import java.util.List;

/**
 * Created by yansen on 17/2/15.
 */
public class OrderFlowworkOperationDataDto implements Serializable{

    private static final long serialVersionUID = 8767237839095224161L;

    public static final int TYPE_FORCE_SUPPLIER_SUCCESS=1;//

    public static final int TYPE_FORCE_SUPPLIER_FAIL=2;//

    public static final int TYPE_MNG_SUPPLIER_SUCCESS=3;//管理员后台上游兑换成功

    public static final int TYPE_MNG_SUPPLIER_FAIL=4;//管理员后台上游兑换失败

    public static final int TYPE_CONSUME_CREDITS_SUCCESS=5;//扣积分成功

    public static final int TYPE_CONSUME_CREDITS_FAIL=6;//扣积分失败
    
    public static final int TYPE_CONSUME_POSTSALE_COMPLETE=7;//售后完成

    /**  苏州银行强制订单失败  */
    public static final int TYPE_SZBANK_FORCE_ORDER_FAIL = 8;
    /**  业务主体变更强制订单失败  */
    public static final int TYPE_SUBJECT_FORCE_ORDER_FAIL = 9;

    public static final int TYPE_CONSUME_POSTSALE_CREDITS = 10;//售后积分

    public static final int TYPE_CANCLE_RECEVIED_CREDITS = 11;//取消发货退积分

    private Integer type;

    private Long orderId;

    private Long appId;

    private Long postsaleOrderNum;

    private Long orderItemId;

    private Boolean isPureCredits;

    private Long postsaleCredits;

    private Long postsaleOrderId;

    private String error4admin;

    private String error4developer;

    private String error4consumer;

    private List<Long> orderItemIds;

    public List<Long> getOrderItemIds() {
        return orderItemIds;
    }

    public void setOrderItemIds(List<Long> orderItemIds) {
        this.orderItemIds = orderItemIds;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Long getOrderId() {
        return orderId;
    }

    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }

    public String getError4admin() {
        return error4admin;
    }

    public void setError4admin(String error4admin) {
        this.error4admin = error4admin;
    }

    public String getError4developer() {
        return error4developer;
    }

    public void setError4developer(String error4developer) {
        this.error4developer = error4developer;
    }

    public String getError4consumer() {
        return error4consumer;
    }

    public void setError4consumer(String error4consumer) {
        this.error4consumer = error4consumer;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getOrderItemId() {
        return orderItemId;
    }

    public void setOrderItemId(Long orderItemId) {
        this.orderItemId = orderItemId;
    }

    public Long getPostsaleCredits() {
        return postsaleCredits;
    }

    public void setPostsaleCredits(Long postsaleCredits) {
        this.postsaleCredits = postsaleCredits;
    }

    public Long getPostsaleOrderNum() {
        return postsaleOrderNum;
    }

    public void setPostsaleOrderNum(Long postsaleOrderNum) {
        this.postsaleOrderNum = postsaleOrderNum;
    }

    public Boolean getPureCredits() {
        return isPureCredits;
    }

    public void setPureCredits(Boolean pureCredits) {
        isPureCredits = pureCredits;
    }

    public Long getPostsaleOrderId() {
        return postsaleOrderId;
    }

    public void setPostsaleOrderId(Long postsaleOrderId) {
        this.postsaleOrderId = postsaleOrderId;
    }
}
